@@ -69,6 +69,9 @@ class JMan:
     def albarans(self):
         return accions.Albarans(con=self._con)
 
+    @property
+    def recepcions(self):
+        return accions.Recepcions(con=self._con)
 
 class JManFb:
     __slots__ = '_con'
